==> haskell-yesod-persistent-1.4.3-114-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.4.3
id: yesod-persistent-1.4.3-KeCqRLiVv4QEiP2d7XNYdj
key: yesod-persistent-1.4.3-KeCqRLiVv4QEiP2d7XNYdj
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
abi: 1a23774fed9ec3f5b40225ca08ad85a9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-persistent-1.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-persistent-1.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/yesod-persistent-1.4.3
hs-libraries: HSyesod-persistent-1.4.3-KeCqRLiVv4QEiP2d7XNYdj
depends:
    base-4.10.1.0 yesod-core-1.4.37.3-LatB9tSWtvM8UYQEZCKNgh
    persistent-2.7.3.1-CyiotN8Is9O2iUcpq9nhBE
    persistent-template-2.5.4-JcsULV6rKgS9VqM4nwdb7n
    transformers-0.5.2.0 blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4
    conduit-1.2.13-ERrJ1zRDAjtBUEDnuFTct7
    resourcet-1.1.11-8WS6etjZjoIGQzjhLftij3
    resource-pool-0.2.3.2-L8h9faiaZdY6WQskuUbSwo
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             yesod-core-1.4.37.3-LatB9tSWtvM8UYQEZCKNgh=fd53a46124deba97ed17fa8f0cdc5bbf
             persistent-2.7.3.1-CyiotN8Is9O2iUcpq9nhBE=553837af2597ddcbd69c53d4f258735c
             persistent-template-2.5.4-JcsULV6rKgS9VqM4nwdb7n=42eda29cd864602bc15e3ce9edbae7ba
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4=df56dd2a069eaa62b68a7725fcf6fae4
             conduit-1.2.13-ERrJ1zRDAjtBUEDnuFTct7=c466781791bf32db2246fdef0bcb0069
             resourcet-1.1.11-8WS6etjZjoIGQzjhLftij3=cf1dc27f76db31da591f7499cde81a83
             resource-pool-0.2.3.2-L8h9faiaZdY6WQskuUbSwo=2d5c156d9c803f2fe417e33029377450
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.4.3-120-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-persistent
version: 1.4.3
id: yesod-persistent-1.4.3-63mm9WU0kyDwjuab8cArq
key: yesod-persistent-1.4.3-63mm9WU0kyDwjuab8cArq
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>
category: Web, Yesod, Database
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Yesod.Persist Yesod.Persist.Core
abi: 5004a84c7f32940ac48e353fbfe05a75
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-persistent-1.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-persistent-1.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/yesod-persistent-1.4.3
hs-libraries: HSyesod-persistent-1.4.3-63mm9WU0kyDwjuab8cArq
depends:
    base-4.10.1.0 yesod-core-1.4.37.3-9JTLBnYK5YB1JjxLwaVwvX
    persistent-2.7.3.1-IhkWR2wRy9uIe45JOvRsyH
    persistent-template-2.5.4-IVeQZNIpKUI3xoLZmxRBws
    transformers-0.5.2.0 blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4
    conduit-1.2.13-ERrJ1zRDAjtBUEDnuFTct7
    resourcet-1.1.11-8WS6etjZjoIGQzjhLftij3
    resource-pool-0.2.3.2-L8h9faiaZdY6WQskuUbSwo
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             yesod-core-1.4.37.3-9JTLBnYK5YB1JjxLwaVwvX=d054c97472a9c213e0607dad7e3efc06
             persistent-2.7.3.1-IhkWR2wRy9uIe45JOvRsyH=673d7eda640c884939b1c7c8499a04cf
             persistent-template-2.5.4-IVeQZNIpKUI3xoLZmxRBws=0ab6b664ae91349cced9f85b496e680d
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4=df56dd2a069eaa62b68a7725fcf6fae4
             conduit-1.2.13-ERrJ1zRDAjtBUEDnuFTct7=c466781791bf32db2246fdef0bcb0069
             resourcet-1.1.11-8WS6etjZjoIGQzjhLftij3=cf1dc27f76db31da591f7499cde81a83
             resource-pool-0.2.3.2-L8h9faiaZdY6WQskuUbSwo=2d5c156d9c803f2fe417e33029377450
haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
haddock-html: /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
